summaryrefslogtreecommitdiffstats
path: root/src/replaygainfilelist.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:05:53 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:05:53 -0600
commit4955fd5009a6f4b615fec006c960c0ed99e3d9a7 (patch)
tree5721cb5c85684019e0649729dca1b90e93934efb /src/replaygainfilelist.cpp
parent5b1e3197e7c9ef6e24eaf7863a7ddea5996e581b (diff)
downloadsoundkonverter-4955fd5009a6f4b615fec006c960c0ed99e3d9a7.tar.gz
soundkonverter-4955fd5009a6f4b615fec006c960c0ed99e3d9a7.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/replaygainfilelist.cpp')
-rwxr-xr-xsrc/replaygainfilelist.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/src/replaygainfilelist.cpp b/src/replaygainfilelist.cpp
index 8d7f4cc..1abbb89 100755
--- a/src/replaygainfilelist.cpp
+++ b/src/replaygainfilelist.cpp
@@ -34,7 +34,7 @@
ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent )
- : KListViewItem( parent )
+ : TDEListViewItem( parent )
{
m_type = File;
mimeType = "application/octet-stream";
@@ -43,7 +43,7 @@ ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent )
}
// ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent, TQListViewItem* after )
-// : KListViewItem( parent, after )
+// : TDEListViewItem( parent, after )
// {
// m_type = File;
// mimeType = "application/octet-stream";
@@ -52,7 +52,7 @@ ReplayGainFileListItem::ReplayGainFileListItem( TQListView* parent )
// }
ReplayGainFileListItem::ReplayGainFileListItem( ReplayGainFileListItem* parent )
- : KListViewItem( parent )
+ : TDEListViewItem( parent )
{
m_type = File;
mimeType = "application/octet-stream";
@@ -115,7 +115,7 @@ void ReplayGainFileListItem::paintCell( TQPainter *p, const TQColorGroup &cg, in
return;
}
- KListViewItem::paintCell( p, _cg, column, width, alignment );
+ TDEListViewItem::paintCell( p, _cg, column, width, alignment );
}
void ReplayGainFileListItem::setType( Type type )
@@ -157,11 +157,11 @@ int ReplayGainFileListItem::compare( TQListViewItem* item, int column, bool asce
// NOTE looking at the types, not the strings would be better
if( text(1) == "" && item->text(1) != "" ) return -1;
else if( text(1) != "" && item->text(1) == "" ) return 1;
- else return KListViewItem::compare( item, column, ascending );
+ else return TDEListViewItem::compare( item, column, ascending );
}
ReplayGainFileList::ReplayGainFileList( TagEngine* _tagEngine, Config* _config, Logger* _logger, TQWidget *parent, const char *name )
- : KListView( parent, name )
+ : TDEListView( parent, name )
{
tagEngine = _tagEngine;
config = _config;
@@ -202,21 +202,21 @@ ReplayGainFileList::ReplayGainFileList( TagEngine* _tagEngine, Config* _config,
grid->addWidget( pScanStatus, 1, 1 );
grid->setColStretch( 1, 2 );
- contextMenu = new KPopupMenu( this );
+ contextMenu = new TDEPopupMenu( this );
connect( TQT_TQOBJECT(this), TQT_SIGNAL(contextMenuRequested(TQListViewItem*,const TQPoint&,int)),
TQT_TQOBJECT(this), TQT_SLOT(showContextMenu(TQListViewItem*,const TQPoint&,int))
);
// we haven't got access to the action collection of soundKonverter, so let's create a new one
- actionCollection = new KActionCollection( this );
+ actionCollection = new TDEActionCollection( this );
- calc_gain = new KAction( i18n("Calculate Replay Gain tags"), "apply", 0, TQT_TQOBJECT(this), TQT_SLOT(calcSelectedItemsGain()), actionCollection, "calc_album" );
- remove_gain = new KAction( i18n("Remove Replay Gain tags"), "cancel", 0, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItemsGain()), actionCollection, "remove_gain" );
- remove = new KAction( i18n("Remove"), "edittrash", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItems()), actionCollection, "remove" );
- paste = new KAction( i18n("Paste"), "editpaste", 0, TQT_TQOBJECT(this), 0, actionCollection, "paste" );
- newalbum = new KAction( i18n("New album"), "filenew", 0, TQT_TQOBJECT(this), TQT_SLOT(createNewAlbum()), actionCollection, "newalbum" );
- open_albums = new KAction( i18n("Open all albums"), "view_tree", 0, TQT_TQOBJECT(this), TQT_SLOT(openAlbums()), actionCollection, "open_albums" );
- close_albums = new KAction( i18n("Cloase all albums"), "view_text", 0, TQT_TQOBJECT(this), TQT_SLOT(closeAlbums()), actionCollection, "close_albums" );
+ calc_gain = new TDEAction( i18n("Calculate Replay Gain tags"), "apply", 0, TQT_TQOBJECT(this), TQT_SLOT(calcSelectedItemsGain()), actionCollection, "calc_album" );
+ remove_gain = new TDEAction( i18n("Remove Replay Gain tags"), "cancel", 0, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItemsGain()), actionCollection, "remove_gain" );
+ remove = new TDEAction( i18n("Remove"), "edittrash", Key_Delete, TQT_TQOBJECT(this), TQT_SLOT(removeSelectedItems()), actionCollection, "remove" );
+ paste = new TDEAction( i18n("Paste"), "editpaste", 0, TQT_TQOBJECT(this), 0, actionCollection, "paste" );
+ newalbum = new TDEAction( i18n("New album"), "filenew", 0, TQT_TQOBJECT(this), TQT_SLOT(createNewAlbum()), actionCollection, "newalbum" );
+ open_albums = new TDEAction( i18n("Open all albums"), "view_tree", 0, TQT_TQOBJECT(this), TQT_SLOT(openAlbums()), actionCollection, "open_albums" );
+ close_albums = new TDEAction( i18n("Cloase all albums"), "view_text", 0, TQT_TQOBJECT(this), TQT_SLOT(closeAlbums()), actionCollection, "close_albums" );
replayGain = new ReplayGain( config, logger );
@@ -268,7 +268,7 @@ int ReplayGainFileList::columnByName( const TQString& name )
void ReplayGainFileList::viewportPaintEvent( TQPaintEvent* e )
{
- KListView::viewportPaintEvent( e );
+ TDEListView::viewportPaintEvent( e );
// the bubble help
if( childCount() == 0 ) {
@@ -340,8 +340,8 @@ void ReplayGainFileList::contentsDragMoveEvent( TQDragMoveEvent *e )
cleanItemHighlighter();
cleanDropVisualizer();
- // the rest is handled by KListView
- KListView::contentsDragMoveEvent( e );
+ // the rest is handled by TDEListView
+ TDEListView::contentsDragMoveEvent( e );
return;
}
@@ -364,8 +364,8 @@ void ReplayGainFileList::contentsDragMoveEvent( TQDragMoveEvent *e )
cleanItemHighlighter();
}
- // the rest is handled by KListView
- KListView::contentsDragMoveEvent( e );
+ // the rest is handled by TDEListView
+ TDEListView::contentsDragMoveEvent( e );
}
void ReplayGainFileList::contentsDropEvent( TQDropEvent *e )